(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     47874,        863]
NotebookOptionsPosition[     47246,        838]
NotebookOutlinePosition[     47605,        854]
CellTagsIndexPosition[     47562,        851]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
This code is written to plot the solution for the Heaviside step function \
solution that we solved for the diffusion equation on an infinite domain. We \
are plotting concentration against space and we are fixing the other two \
parameters d and t at various values denoted in \[OpenCurlyQuote]parameters\
\[CloseCurlyQuote].\
\>", "Text",
 CellChangeTimes->{{3.6286876441946707`*^9, 3.628687754508905*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Solution", "[", 
    RowBox[{"{", 
     RowBox[{"d_", ",", "t_"}], "}"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"1", "/", "2"}], "*", 
    RowBox[{"Erfc", "[", 
     RowBox[{"x", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"4", "*", "d", "*", "t"}], "]"}]}], "]"}]}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.628685134940679*^9, 3.628685234552115*^9}, {
   3.628685430420969*^9, 3.628685486546772*^9}, {3.628687726539342*^9, 
   3.6286877358377132`*^9}, {3.6286877998230047`*^9, 3.628687847318308*^9}, 
   3.628688048591518*^9}],

Cell["\<\
Now we define the parameters d and t. here we choose four cases to plot, in \
each we keep d=1 and then we consider 4 cases with t = 1, 10, 100, 1000\
\>", "Text",
 CellChangeTimes->{{3.628687893645811*^9, 3.628687933317349*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"parameters", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "100"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1000"}], "}"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\n"}]], "Input",
 CellChangeTimes->{3.628687863927252*^9, 3.6286880462570133`*^9}],

Cell["\<\
Finally we plot the Solution for these four different sets of parameters\
\>", "Text",
 CellChangeTimes->{{3.628687946964241*^9, 3.628687960110403*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Solution", "/@", "parameters"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "100"}], ",", "100"}], "}"}], ",", 
   RowBox[{"Evaluated", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.628687965774187*^9, 3.6286880286328573`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJxF2Hk0Vd/bAHCEzFPmebzIFPlK3Hv2RiVkJjIns8hcVIaKyhgSKUIoyphG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     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJxF2nk8VN8fP/BKiST7Lvu+NcYY29x7ztiKKDttSEooW7QgKUuSPSJEhEqK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     "]]}, 
   {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwt23k8VN/7APBColAo2bIrJNn3uefYd2aGGUMlSlEkO6GyhwhFKFGyhSgU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     "]]}, 
   {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwtlWs41HkfxhESSdQj2WyrQjbaQsjp+7M5rGRlzOEvQhR6EKl1JtuBzCCH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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{453.15234375, Automatic},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{-100, 100}, {0., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.6286878694868717`*^9, {3.628687967418565*^9, 3.6286880290000973`*^9}}]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{{3.628687995871523*^9, 3.628688012280863*^9}},
 NumberMarks->False],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.628688007057432*^9, 3.6286880070769567`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.628687850197242*^9, 3.6286878502148733`*^9}}]
},
WindowSize->{808, 552},
WindowMargins->{{809, Automatic}, {Automatic, 310}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 418, 7, 68, "Text"],
Cell[979, 29, 624, 16, 63, "Input"],
Cell[1606, 47, 239, 4, 49, "Text"],
Cell[1848, 53, 508, 15, 80, "Input"],
Cell[2359, 70, 162, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[2546, 77, 377, 9, 28, "Input"],
Cell[2926, 88, 43975, 737, 296, "Output"]
}, Open  ]],
Cell[46916, 828, 132, 2, 46, "Input"],
Cell[47051, 832, 94, 1, 28, "Input"],
Cell[47148, 835, 94, 1, 28, "Input"]
}
]
*)

(* End of internal cache information *)
