(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     21060,        671]
NotebookOptionsPosition[     18953,        602]
NotebookOutlinePosition[     19311,        618]
CellTagsIndexPosition[     19268,        615]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
This code solves the problem in Example 2 from Chapter 3 - the solution to a \
diffusion equation with a continuous source at x=1;

First let us define Greens function for this problem\
\>", "Text",
 CellChangeTimes->{{3.630347505020493*^9, 3.630347572931473*^9}, {
  3.6303483075053177`*^9, 3.630348324320458*^9}}],

Cell[BoxData[
 RowBox[{"G", ":=", 
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"4", "*", "Pi", "*", "d", "*", 
      RowBox[{"(", 
       RowBox[{"t", "-", "tau"}], ")"}]}], "]"}]}], "*", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", "xi"}], ")"}], "^", "2"}]}], "/", 
     RowBox[{"(", 
      RowBox[{"4", "*", "d", "*", 
       RowBox[{"(", 
        RowBox[{"t", "-", "tau"}], ")"}]}], ")"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.630347576188456*^9, 3.630347622507669*^9}, {
  3.630348329345392*^9, 3.63034833967306*^9}}],

Cell["\<\
Note that since for this problem phi is not zero we must keep the (t-tau) \
terms in the Greens function

Now the solution to the problem is given by the integral of the source and \
the Greens function

The source is given by C(x,t)=dirac(-x) where dirac is the dirac delta \
function.

Therefore\
\>", "Text",
 CellChangeTimes->{{3.630347645756174*^9, 3.63034775354679*^9}, {
  3.630348345640628*^9, 3.6303484074722757`*^9}}],

Cell[BoxData[
 RowBox[{"f", ":=", 
  RowBox[{"DiracDelta", "[", "xi", "]"}]}]], "Input",
 CellChangeTimes->{{3.630347757823154*^9, 3.630347767099032*^9}, 
   3.630347818419096*^9, {3.630348412764041*^9, 3.6303484528734303`*^9}, {
   3.630348630369792*^9, 3.630348635767993*^9}}],

Cell["\<\
Note that we define the source with xi, the Greens function variable, rather \
than x (look at the solution on slide ). The source is constant over all time \
so therefore we do not have to worry about t or tau. The solution is now \
given by performing the integration\[LineSeparator]\[LineSeparator]Let\
\[CloseCurlyQuote]s integrate over xi first\
\>", "Text",
 CellChangeTimes->{{3.63034777838717*^9, 3.630347784498679*^9}, {
  3.6303478246111593`*^9, 3.630347872938396*^9}, {3.630348457936205*^9, 
  3.630348496120078*^9}, {3.630348572367675*^9, 3.6303485839274273`*^9}}],

Cell[BoxData[
 RowBox[{"Sol1", ":=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"f", "*", "G"}], ",", 
    RowBox[{"{", 
     RowBox[{"xi", ",", 
      RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.630347794139696*^9, 3.63034781465963*^9}, {
  3.630347876954858*^9, 3.6303479226183662`*^9}, {3.6303485063948107`*^9, 
  3.630348531200457*^9}, {3.63034859159435*^9, 3.6303486100239162`*^9}, {
  3.630348643585903*^9, 3.630348644631652*^9}}],

Cell[CellGroupData[{

Cell[BoxData["Sol1"], "Input",
 CellChangeTimes->{{3.6303479247058983`*^9, 3.63034792747442*^9}, {
  3.630348613431963*^9, 3.6303486151619787`*^9}}],

Cell[BoxData[
 FractionBox[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox["x", "2"], 
     RowBox[{
      RowBox[{"4", " ", "d", " ", "t"}], "-", 
      RowBox[{"4", " ", "d", " ", "tau"}]}]]}]], 
  RowBox[{"2", " ", 
   SqrtBox["\[Pi]"], " ", 
   SqrtBox[
    RowBox[{"d", " ", 
     RowBox[{"(", 
      RowBox[{"t", "-", "tau"}], ")"}]}]]}]]], "Output",
 CellChangeTimes->{3.6303479296649446`*^9, 3.630348544238762*^9, 
  3.630348621274023*^9, 3.63034865135674*^9, 3.630348804426468*^9, 
  3.630351070817944*^9, 3.630351266824292*^9, 3.630405951980702*^9}]
}, Open  ]],

Cell[TextData[{
 "Does this make sense to you? Recall that when you integrate a function \
multiplied by the delta function you get the function back with the integrand \
equal to the value of the location of the delta pulse (i.e. xi=0). So this is \
why we get G back with xi=0.\n\nPhysicall this equation is telling you that \
for each pulse that is introduced into the system at each time (recall you \
are cnotinuusly supplying mass) you get a Gaussia distribution.",
 StyleBox["\n",
  FontSlant->"Italic"],
 "\nNow to obtain the final solution you have to perform the integration over \
time"
}], "Text",
 CellChangeTimes->{{3.630347943050865*^9, 3.630347965978066*^9}, {
  3.630348671887411*^9, 3.630348775319027*^9}, {3.6303488227034817`*^9, 
  3.630348889070466*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.6303479008665657`*^9, 3.630347917084071*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.630348898678384*^9, 3.630348898683744*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{"Sol1", ",", 
   RowBox[{"{", 
    RowBox[{"tau", ",", "0", ",", "t"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.630348000277197*^9, 3.630348022418231*^9}, {
  3.630348903049288*^9, 3.630348924384857*^9}, {3.630348970590992*^9, 
  3.6303490002648573`*^9}, {3.6303491357296047`*^9, 3.630349139558145*^9}}],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Integral]", "0", "t"], 
  RowBox[{
   FractionBox[
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["x", "2"], 
       RowBox[{
        RowBox[{"4", " ", "d", " ", "t"}], "-", 
        RowBox[{"4", " ", "d", " ", "tau"}]}]]}]], 
    RowBox[{"2", " ", 
     SqrtBox["\[Pi]"], " ", 
     SqrtBox[
      RowBox[{"d", " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "tau"}], ")"}]}]]}]], 
   RowBox[{"\[DifferentialD]", "tau"}]}]}]], "Output",
 CellChangeTimes->{3.630349012495295*^9, 3.630349143847824*^9, 
  3.630351097333811*^9, 3.630351292389282*^9, 3.630405974890294*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not like this expression - if you look carefully it is because you \
are asking it evaluate something a tau=t and the denominator blows up there, \
causing difficulties, but there is a work around (for engineers - foral \
mathematicians would not like it - hence ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not like it.\n\nWhen this happens go through a gut check - is your \
expression correct? Check the mathematics and you will see yes it is. Let\
\[CloseCurlyQuote]s also think about the physics - what does the integral \
above mean? And is that consistent with your physical reasoning of the \
problem - remember the mathematics is telling a story that should be the same \
story as what is physically happening. You should come to the conclusion that \
it is physically consistent (we will discuss this in class).\n\nOk - so the \
equation is correct, but ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not like it. This is a good experience, because it shows you where ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can fail you, but where you can use your knowledge to work around its \
limitations.\n\nIn stead of trying to do the definite integral, let\
\[CloseCurlyQuote]s do the indefinite integral (since we know the problem \
arises because one of the boundary terms - i.e. where tau=t)"
}], "Text",
 CellChangeTimes->{{3.630349165046484*^9, 3.630349249637506*^9}, {
  3.63034934410174*^9, 3.630349376949027*^9}, {3.630405308889804*^9, 
  3.6304054661008387`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.630348029045702*^9, 3.63034803028211*^9}, 
   3.630349152416957*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{"Sol1", ",", "tau"}], "]"}]], "Input",
 CellChangeTimes->{{3.630349261063696*^9, 3.63034926318375*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["x", "2"], 
       RowBox[{
        RowBox[{"4", " ", "d", " ", "t"}], "-", 
        RowBox[{"4", " ", "d", " ", "tau"}]}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t"}], "+", "tau"}], ")"}]}], "-", 
   FractionBox[
    RowBox[{
     SqrtBox["\[Pi]"], " ", 
     SqrtBox[
      RowBox[{"t", "-", "tau"}]], " ", "x", " ", 
     RowBox[{"Erf", "[", 
      FractionBox["x", 
       RowBox[{"2", " ", 
        SqrtBox["d"], " ", 
        SqrtBox[
         RowBox[{"t", "-", "tau"}]]}]], "]"}]}], 
    SqrtBox["d"]]}], 
  RowBox[{"2", " ", 
   SqrtBox["\[Pi]"], " ", 
   SqrtBox[
    RowBox[{"d", " ", 
     RowBox[{"(", 
      RowBox[{"t", "-", "tau"}], ")"}]}]]}]]], "Output",
 CellChangeTimes->{3.630349263652575*^9, 3.630351097629315*^9, 
  3.6303513057675447`*^9, 3.63040597512322*^9}]
}, Open  ]],

Cell["", "Text"],

Cell["\<\
Now let\[CloseCurlyQuote]s look at what this looks like when tau=0 (the lower \
boundary)\
\>", "Text",
 CellChangeTimes->{{3.630349393597638*^9, 3.6303494076769114`*^9}, {
  3.6303510909187193`*^9, 3.630351091102647*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.630349154165513*^9, 3.630349154171359*^9}}],

Cell[BoxData[
 RowBox[{"Slower", ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["x", "2"], 
        RowBox[{"4", " ", "d", " ", "t"}]]}]], " ", 
     RowBox[{"(", 
      RowBox[{"-", "t"}], ")"}]}], "-", 
    FractionBox[
     RowBox[{
      SqrtBox["\[Pi]"], " ", 
      SqrtBox["t"], " ", "x", " ", 
      RowBox[{"Erf", "[", 
       FractionBox["x", 
        RowBox[{"2", " ", 
         SqrtBox["d"], " ", 
         SqrtBox["t"]}]], "]"}]}], 
     SqrtBox["d"]]}], 
   RowBox[{"2", " ", 
    SqrtBox["\[Pi]"], " ", 
    SqrtBox[
     RowBox[{"d", " ", 
      RowBox[{"(", "t", ")"}]}]]}]]}]], "Input",
 CellChangeTimes->{{3.6303494116059513`*^9, 3.63034944058352*^9}}],

Cell[CellGroupData[{

Cell[BoxData["Slower"], "Input",
 CellChangeTimes->{{3.63034944344949*^9, 3.6303494464450073`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["x", "2"], 
       RowBox[{"4", " ", "d", " ", "t"}]]}]], " ", "t"}], "-", 
   FractionBox[
    RowBox[{
     SqrtBox["\[Pi]"], " ", 
     SqrtBox["t"], " ", "x", " ", 
     RowBox[{"Erf", "[", 
      FractionBox["x", 
       RowBox[{"2", " ", 
        SqrtBox["d"], " ", 
        SqrtBox["t"]}]], "]"}]}], 
    SqrtBox["d"]]}], 
  RowBox[{"2", " ", 
   SqrtBox["\[Pi]"], " ", 
   SqrtBox[
    RowBox[{"d", " ", "t"}]]}]]], "Output",
 CellChangeTimes->{3.630349446949189*^9, 3.630351314212659*^9, 
  3.6304059751792*^9}]
}, Open  ]],

Cell["\<\
No problems here, because there is no singularity

What about when tau=t

Well here you have a potentail problem\
\>", "Text",
 CellChangeTimes->{{3.630349488101419*^9, 3.630349543556231*^9}}],

Cell["Let\[CloseCurlyQuote]s break the epression for Sol1 it into 2 parts", \
"Text",
 CellChangeTimes->{{3.6303480517624493`*^9, 3.630348169409011*^9}, {
   3.630348221978837*^9, 3.630348252272812*^9}, 3.6303491577495613`*^9, {
   3.630350182779138*^9, 3.6303501918340816`*^9}, {3.630405502301519*^9, 
   3.630405505980097*^9}}],

Cell[BoxData[
 RowBox[{"Part1", ":=", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["x", "2"], 
       RowBox[{
        RowBox[{"4", " ", "d", " ", "t"}], "-", 
        RowBox[{"4", " ", "d", " ", "tau"}]}]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "t"}], "+", "tau"}], ")"}]}], 
   RowBox[{"2", " ", 
    SqrtBox["\[Pi]"], " ", 
    SqrtBox[
     RowBox[{"d", " ", 
      RowBox[{"(", 
       RowBox[{"t", "-", "tau"}], ")"}]}]]}]]}]], "Input",
 CellChangeTimes->{{3.630349552038031*^9, 3.630349598288125*^9}, {
  3.6303501001448402`*^9, 3.6303501168352623`*^9}, {3.630350197765674*^9, 
  3.630350205087265*^9}}],

Cell["\<\
What happens when tau=t - You get exp (-infinity)*0/sqrt(0), which is \
technically undefined, but the numerator goes to zero more quickly than the \
denominator so we will say it is 0.\
\>", "Text",
 CellChangeTimes->{{3.63035021707477*^9, 3.6303502718579817`*^9}}],

Cell[BoxData[
 RowBox[{"Part2", ":=", 
  RowBox[{"-", 
   FractionBox[
    FractionBox[
     RowBox[{
      SqrtBox["\[Pi]"], " ", 
      SqrtBox[
       RowBox[{"t", "-", "tau"}]], " ", "x", " ", 
      RowBox[{"Erf", "[", 
       FractionBox["x", 
        RowBox[{"2", " ", 
         SqrtBox["d"], " ", 
         SqrtBox[
          RowBox[{"t", "-", "tau"}]]}]], "]"}]}], 
     SqrtBox["d"]], 
    RowBox[{"2", " ", 
     SqrtBox["\[Pi]"], " ", 
     SqrtBox[
      RowBox[{"d", " ", 
       RowBox[{"(", 
        RowBox[{"t", "-", "tau"}], ")"}]}]]}]]}]}]], "Input",
 CellChangeTimes->{{3.630350295960307*^9, 3.630350311277767*^9}, 
   3.630351236992258*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Part2", ",", 
   RowBox[{
    RowBox[{"t", ">", "tau"}], " ", "&&", " ", 
    RowBox[{"tau", ">", "0"}], " ", "&&", 
    RowBox[{"d", ">", "0"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.630350317375575*^9, 3.630350369572888*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"x", " ", 
    RowBox[{"Erf", "[", 
     FractionBox["x", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"d", " ", 
         RowBox[{"(", 
          RowBox[{"t", "-", "tau"}], ")"}]}]]}]], "]"}]}], 
   RowBox[{"2", " ", "d"}]]}]], "Output",
 CellChangeTimes->{
  3.630350331041238*^9, {3.630350362916992*^9, 3.630350369867435*^9}, 
   3.63035132698822*^9, 3.630405975228136*^9}]
}, Open  ]],

Cell["\<\
Now we have erf(x/0), which is erf(+ or - infinity, because x acan be \
positive or negative), which is + or - 1 so Part2 simplifies to + or - x/2d \
depending on if x is positive or negtive. This can be taken care of with an \
absolute value of x

That is

-abs(x)/2d

So finally we can lump it all together

Solution =Part1+Part2-Slower, which is\
\>", "Text",
 CellChangeTimes->{{3.630350406282075*^9, 3.630350422681305*^9}, {
  3.6303504866172733`*^9, 3.6303504980890827`*^9}, {3.630350538369059*^9, 
  3.630350556528799*^9}, {3.6303507923129396`*^9, 3.63035084014393*^9}, {
  3.6303509346714487`*^9, 3.630350935391582*^9}, {3.630351362293754*^9, 
  3.630351374717667*^9}, {3.630351413933586*^9, 3.6303514245176086`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.630350930063716*^9, 3.630350932930442*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"0", "-", 
  FractionBox[
   RowBox[{
    RowBox[{"Abs", "[", "x", "]"}], " "}], 
   RowBox[{"2", " ", "d"}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["x", "2"], 
        RowBox[{"4", " ", "d", " ", "t"}]]}]], " ", "t"}], "-", 
    FractionBox[
     RowBox[{
      SqrtBox["\[Pi]"], " ", 
      SqrtBox["t"], " ", "x", " ", 
      RowBox[{"Erf", "[", 
       FractionBox["x", 
        RowBox[{"2", " ", 
         SqrtBox["d"], " ", 
         SqrtBox["t"]}]], "]"}]}], 
     SqrtBox["d"]]}], 
   RowBox[{"2", " ", 
    SqrtBox["\[Pi]"], " ", 
    SqrtBox[
     RowBox[{"d", " ", "t"}]]}]]}]], "Input",
 CellChangeTimes->{{3.6303505632023087`*^9, 3.630350608363316*^9}, 
   3.630350926890854*^9, {3.630351433353076*^9, 3.630351441462487*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"Abs", "[", "x", "]"}], 
    RowBox[{"2", " ", "d"}]]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        SuperscriptBox["x", "2"], 
        RowBox[{"4", " ", "d", " ", "t"}]]}]], " ", "t"}], "-", 
    FractionBox[
     RowBox[{
      SqrtBox["\[Pi]"], " ", 
      SqrtBox["t"], " ", "x", " ", 
      RowBox[{"Erf", "[", 
       FractionBox["x", 
        RowBox[{"2", " ", 
         SqrtBox["d"], " ", 
         SqrtBox["t"]}]], "]"}]}], 
     SqrtBox["d"]]}], 
   RowBox[{"2", " ", 
    SqrtBox["\[Pi]"], " ", 
    SqrtBox[
     RowBox[{"d", " ", "t"}]]}]]}]], "Output",
 CellChangeTimes->{3.6303509272415447`*^9, 3.630351442206843*^9, 
  3.630405975265971*^9}]
}, Open  ]],

Cell["Let\[CloseCurlyQuote]s clean this up a little", "Text",
 CellChangeTimes->{{3.6303509422961693`*^9, 3.630350948015255*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.630350632932148*^9, 3.6303506344202957`*^9}, 
   3.630350919373431*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["x", "2"], 
       RowBox[{"4", " ", "d", " ", "t"}]]}]], " ", "t"}], 
   RowBox[{
    SqrtBox["\[Pi]"], " ", 
    SqrtBox[
     RowBox[{"d", " ", "t"}]]}]], "-", 
  FractionBox[
   RowBox[{"Abs", "[", "x", "]"}], 
   RowBox[{"2", " ", "d"}]], "+", 
  FractionBox[
   RowBox[{"x", " ", 
    RowBox[{"Erf", "[", 
     FractionBox["x", 
      RowBox[{"2", " ", 
       SqrtBox["d"], " ", 
       SqrtBox["t"]}]], "]"}]}], 
   RowBox[{"2", " ", "d"}]]}]], "Input",
 CellChangeTimes->{{3.630350955368587*^9, 3.63035100191965*^9}, {
  3.630405623889369*^9, 3.6304057180187817`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["x", "2"], 
       RowBox[{"4", " ", "d", " ", "t"}]]}]], " ", "t"}], 
   RowBox[{
    SqrtBox["\[Pi]"], " ", 
    SqrtBox[
     RowBox[{"d", " ", "t"}]]}]], "-", 
  FractionBox[
   RowBox[{"Abs", "[", "x", "]"}], 
   RowBox[{"2", " ", "d"}]], "+", 
  FractionBox[
   RowBox[{"x", " ", 
    RowBox[{"Erf", "[", 
     FractionBox["x", 
      RowBox[{"2", " ", 
       SqrtBox["d"], " ", 
       SqrtBox["t"]}]], "]"}]}], 
   RowBox[{"2", " ", "d"}]]}]], "Output",
 CellChangeTimes->{{3.630405706394679*^9, 3.6304057195910378`*^9}, 
   3.630405975301818*^9}]
}, Open  ]],

Cell["\<\
We now have a solution that really does not look so bad and consists of the \
types of terms we might expect, Gausians and error functions. Let\
\[CloseCurlyQuote]s plot it - for that open Chapter3-Ex2plot\
\>", "Text",
 CellChangeTimes->{{3.630405877554924*^9, 3.63040593382568*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.630350920871581*^9, 3.630350920878496*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.630350638992178*^9, 3.63035064232097*^9}, 
   3.630350922394841*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.63035092356761*^9, 3.630350923573615*^9}}]
},
WindowSize->{808, 911},
WindowMargins->{{18, Automatic}, {Automatic, 140}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 325, 7, 87, "Text"],
Cell[886, 29, 632, 19, 28, "Input"],
Cell[1521, 50, 437, 13, 144, "Text"],
Cell[1961, 65, 278, 5, 28, "Input"],
Cell[2242, 72, 586, 9, 106, "Text"],
Cell[2831, 83, 501, 12, 28, "Input"],
Cell[CellGroupData[{
Cell[3357, 99, 148, 2, 28, "Input"],
Cell[3508, 103, 603, 17, 67, "Output"]
}, Open  ]],
Cell[4126, 123, 775, 14, 163, "Text"],
Cell[4904, 139, 94, 1, 28, "Input"],
Cell[5001, 142, 92, 1, 28, InheritFromParent],
Cell[CellGroupData[{
Cell[5118, 147, 363, 7, 28, "Input"],
Cell[5484, 156, 674, 20, 67, "Output"]
}, Open  ]],
Cell[6173, 179, 1589, 29, 296, "Text"],
Cell[7765, 210, 117, 2, 28, "Input"],
Cell[CellGroupData[{
Cell[7907, 216, 155, 3, 28, "Input"],
Cell[8065, 221, 966, 33, 74, "Output"]
}, Open  ]],
Cell[9046, 257, 16, 0, 30, "Text"],
Cell[9065, 259, 232, 5, 30, "Text"],
Cell[9300, 266, 92, 1, 28, InheritFromParent],
Cell[9395, 269, 784, 27, 79, "Input"],
Cell[CellGroupData[{
Cell[10204, 300, 99, 1, 28, "Input"],
Cell[10306, 303, 700, 25, 75, "Output"]
}, Open  ]],
Cell[11021, 331, 202, 7, 106, "Text"],
Cell[11226, 340, 329, 5, 30, "Text"],
Cell[11558, 347, 724, 22, 69, "Input"],
Cell[12285, 371, 276, 5, 49, "Text"],
Cell[12564, 378, 661, 23, 79, "Input"],
Cell[CellGroupData[{
Cell[13250, 405, 284, 7, 28, "Input"],
Cell[13537, 414, 444, 14, 60, "Output"]
}, Open  ]],
Cell[13996, 431, 735, 18, 220, "Text"],
Cell[14734, 451, 92, 1, 28, "Input"],
Cell[CellGroupData[{
Cell[14851, 456, 903, 30, 78, "Input"],
Cell[15757, 488, 846, 30, 75, "Output"]
}, Open  ]],
Cell[16618, 521, 129, 1, 30, "Text"],
Cell[16750, 524, 120, 2, 28, "Input"],
Cell[CellGroupData[{
Cell[16895, 530, 727, 25, 69, "Input"],
Cell[17625, 557, 706, 25, 67, "Output"]
}, Open  ]],
Cell[18346, 585, 294, 5, 49, "Text"],
Cell[18643, 592, 92, 1, 28, InheritFromParent],
Cell[18738, 595, 117, 2, 28, "Input"],
Cell[18858, 599, 91, 1, 62, InheritFromParent]
}
]
*)

(* End of internal cache information *)
