(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     52204,        954]
NotebookOptionsPosition[     51399,        925]
NotebookOutlinePosition[     51758,        941]
CellTagsIndexPosition[     51715,        938]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
This code is written to plot the solution for the constant source at x=0 that \
we solved for the diffusion equation on an infinite domain. We are plotting \
concentration against space and we are fixing the other two parameters d and \
t at various values denoted in \[OpenCurlyQuote]parameters\[CloseCurlyQuote].\
\
\>", "Text",
 CellChangeTimes->{{3.6286876441946707`*^9, 3.628687754508905*^9}, {
  3.630351736133225*^9, 3.630351748372304*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Solution", "[", 
    RowBox[{"{", 
     RowBox[{"d_", ",", "t_"}], "}"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         SuperscriptBox["x", "2"], 
         RowBox[{"4", " ", "d", " ", "t"}]]}]], " ", "t"}], 
     RowBox[{
      SqrtBox["\[Pi]"], " ", 
      SqrtBox[
       RowBox[{"d", " ", "t"}]]}]], "-", 
    FractionBox[
     RowBox[{"Abs", "[", "x", "]"}], 
     RowBox[{"2", " ", "d"}]], "+", 
    FractionBox[
     RowBox[{"x", " ", 
      RowBox[{"Erf", "[", 
       FractionBox["x", 
        RowBox[{"2", " ", 
         SqrtBox["d"], " ", 
         SqrtBox["t"]}]], "]"}]}], 
     RowBox[{"2", " ", "d"}]]}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.628685134940679*^9, 3.628685234552115*^9}, {
   3.628685430420969*^9, 3.628685486546772*^9}, {3.628687726539342*^9, 
   3.6286877358377132`*^9}, {3.6286877998230047`*^9, 3.628687847318308*^9}, 
   3.628688048591518*^9, {3.6303506793421288`*^9, 3.630350697180955*^9}, {
   3.630351162116171*^9, 3.630351185416361*^9}, 3.630351464225378*^9, 
   3.630405731944632*^9}],

Cell["\<\
Now we define the parameters d and t. here we choose four cases to plot, in \
each we keep d=1 and then we consider 4 cases with t = 1, 10, 100, 1000\
\>", "Text",
 CellChangeTimes->{{3.628687893645811*^9, 3.628687933317349*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"parameters", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "100"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2000"}], "}"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\n"}]], "Input",
 CellChangeTimes->{
  3.628687863927252*^9, 3.6286880462570133`*^9, {3.630351499897356*^9, 
   3.630351533029554*^9}, {3.630351680822197*^9, 3.6303517051809673`*^9}}],

Cell["\<\
Finally we plot the Solution for these four different sets of parameters\
\>", "Text",
 CellChangeTimes->{{3.628687946964241*^9, 3.628687960110403*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Solution", "/@", "parameters"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "100"}], ",", "100"}], "}"}], ",", 
   RowBox[{"Evaluated", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.628687965774187*^9, 3.6286880286328573`*^9}, {
  3.630351512963162*^9, 3.6303515150384817`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJxF2Wk8VN8fwPFLZF9DKCFZypKWP8K9Z0iSfYtIshORvRIaQiU7RRRDyFZJ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     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJxF23k0lF8YwPEpKVTIniQ7FWXLEu+9Q8iWXZYk+dlCohCSZE/2bFFCiJIl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     "]]}, 
   {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJw13Gk0VlsYB/BXJEKZU4RMIWSez94nIUmGQipXSAhlnqU3IYkMUZKQkCka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     "]]}, 
   {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwBgQF+/iFib1JlAgAAABcAAAACAAAAXGHh7v//WMAgPtD/1ZX4PxLLXvIS
/FjAAOhZ0Cak+D/INNz1JfhYwCBF+8R+svg/MwjX/EvwWMAg87slRM/4Pwqv
zAqY4FjAQPPZEyUJ+T+5/LcmMMFYwCAu1xlCfvk/FpiOXmCCWMCA+a2p/G36
P9HOO87ABFjAIM2f4RRk/D+L0D+AX/RWwOB1SRNOiQBAngkMCgv2VcDwisck
XgIDQFjuQL+z/FTAYP6tjXm6BUBXZx9HOu5TwJDhWZ6yCQlArxfGps3xUsBA
PQk7RX4MQExcFtk+4FHAJD0fYOtVEECRTM82rdNQwBjkKmWEnxJAXeig2FCy
T8B0byK43vsUQCJg9ugCk03AbPhmqADPF0CZRtyozpdLwPCAyTrQtRpAX4ST
v5SmScBi5nagQtEdQK/qnXsWi0fAIXOBdOK/IECxvzjnsZNFwNqji/DFniJA
Pb0m+AhyQ8D/UPUbntIkQP4HcJOMXUHADFUqAs0nJ0B8pbo9
     "]], 
    LineBox[CompressedData["
1:eJwBcQKO/SFib1JlAgAAACYAAAACAAAALI9DQnxeQUAMVSoCzScnQD7CncCP
XENAHh20b8npJEDUfs/7ZVNFQFdKIjXB3iJA4BKukYB0R0CrJi7ti9QgQDo4
/HeBcUlASOCr/T8qHkBFBnkHiGRLQEgffcOzBBtAxqui8dKBTUBcmOeEFOcX
QJXiOywEe09AEEoLtCxCFUBt+MDgPM9QQGxtEr+5qRJA6FP7f/rbUUDU+7P3
vV4QQAp4bUer1lJAqJD4VxDjDEDnBzY8fuZTQJAii7NqIwlAa2A2WUTkVEDg
pKAy9QIGQEgNzkoN3VVAsAwcP6lEA0DgJbxp+OpWQNCs7TZnnwBAHwfisNbm
V0Bgrln6N+D8P4gE2lU761dAgPRRQeDN/D/wAdL6n+9XQMAzJXWSu/w/wvzB
RGn4V0AAu6+SFJf8P2byodj7CVhAQB3SMI9O/D+u3WEAIS1YQKDMdlhav/s/
PrThT2tzWEDATu2CK6j6P6ex2fTPd1hAIG9QZAmX+j8Qr9GZNHxYQKDhDa/w
hfo/4qnB4/2EWEAABWtw22P6P4afoXeQllhAgBauMSEg+j/NimGftblYQEBO
rClqmvk/NohZRBq+WECg2JG93In5P56FUel+wlhAoOCUelh5+T9wgEEzSMtY
QADzB2BrWPk/FHYhx9rcWEDgVmtp/hb5P31zGWw/4VhAINn+1rkG+T/mcBER
pOVYQACd801+9vg/uGsBW23uWEBgVjZIItb4PyFp+f/R8lhAQJWhwwHG+D+K
ZvGkNvdYQGCpqDjqtfg/82PpSZv7WEDgy1yj26X4P1xh4e7//1hAID7Q/9WV
+D95LyfE
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->Large,
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{-100, 100}, {-3.552713678800501*^-15, 11.57773596541167}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.6286878694868717`*^9, {3.628687967418565*^9, 3.6286880290000973`*^9}, 
   3.6303507156792603`*^9, {3.630351173758934*^9, 3.630351190995294*^9}, 
   3.6303514764517107`*^9, {3.630351506804579*^9, 3.6303515356236*^9}, {
   3.6303516857889023`*^9, 3.630351707152076*^9}, 3.630405737977242*^9, 
   3.6304059875009747`*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.630351632688169*^9},
 NumberMarks->False],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.630351628309496*^9, 3.630351628322473*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.630351627201528*^9},
 NumberMarks->False],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.630351624493656*^9, 3.630351624505443*^9}}],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{{3.628687995871523*^9, 3.628688012280863*^9}},
 NumberMarks->False],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.628688007057432*^9, 3.6286880070769567`*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.628687850197242*^9, 3.6286878502148733`*^9}}]
},
WindowSize->{808, 552},
WindowMargins->{{862, Automatic}, {Automatic, 143}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 457, 8, 68, "Text"],
Cell[1018, 30, 1219, 35, 108, "Input"],
Cell[2240, 67, 239, 4, 49, "Text"],
Cell[2482, 73, 609, 17, 80, "Input"],
Cell[3094, 92, 162, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[3281, 99, 427, 10, 28, "Input"],
Cell[3711, 111, 46969, 787, 372, "Output"]
}, Open  ]],
Cell[50695, 901, 89, 2, 28, "Input"],
Cell[50787, 905, 92, 1, 28, InheritFromParent],
Cell[50882, 908, 89, 2, 28, "Input"],
Cell[50974, 912, 92, 1, 28, InheritFromParent],
Cell[51069, 915, 132, 2, 46, "Input"],
Cell[51204, 919, 94, 1, 28, "Input"],
Cell[51301, 922, 94, 1, 28, "Input"]
}
]
*)

(* End of internal cache information *)
